@@ -1,7 +1,7 @@
 #[cfg(any(feature = "i386", feature = "x86_64"))]
 pub type CPUArchPtr = *mut panda_sys::CPUX86State;
 
-#[cfg(feature = "arm")]
+#[cfg(any(feature = "arm", feature = "aarch64"))]
 pub type CPUArchPtr = *mut panda_sys::CPUARMState;
 
 #[cfg(any(feature = "mips", feature = "mipsel"))]
@@ -15,4 +15,4 @@ macro_rules! cpu_arch_state {
     ($cpu:expr) => {
         $cpu.env_ptr as CPUArchPtr
     }
-}
\ No newline at end of file
+}
