@@ -23,9 +23,16 @@
 //! PANDA `build` folder.
 
 /// Raw bindings to the PANDA API
+#[doc(inline)]
 pub use panda_sys as sys;
-pub use panda_macros::*;
-pub use panda_macros as base_callbacks;
+//pub use panda_macros::*;
+
+/// PANDA callback macros
+#[doc(inline)]
+pub use panda_macros as cbs;
+
+/// Callbacks for linux syscalls (from syscalls2)
+pub mod on_sys;
 
 /// Safe wrappers for the libpanda API for helping create and manage an instance of the PANDA API
 mod library_mode;
@@ -47,12 +54,16 @@ pub use inventory;
 
 /// Helpers for getting plugin arguments from panda
 pub mod panda_arg;
+
+#[doc(inline)]
 pub use panda_arg::PandaArgs;
 
 pub mod enums;
 pub mod plugins;
 pub mod taint;
 
+pub use enums::arch::*;
+
 pub mod prelude {
     pub use crate::Panda;
     pub use crate::PluginHandle;
@@ -65,3 +76,61 @@ pub mod prelude {
     pub use crate::panda_arg::PandaArgs;
     pub use panda_macros::PandaArgs;
 }
+
+// callbacks
+pub use panda_macros::{
+    after_block_exec,
+    after_block_translate,
+    after_cpu_exec_enter,
+    after_insn_exec,
+    after_insn_translate,
+    after_loadvm,
+    after_machine_init,
+    asid_changed,
+    before_block_exec,
+    before_block_exec_invalidate_opt,
+    before_block_translate,
+    before_cpu_exec_exit,
+    before_handle_exception,
+    before_handle_interrupt,
+    before_loadvm,
+    cpu_restore_state,
+    during_machine_init,
+    guest_hypercall,
+    hd_read,
+    hd_write,
+    init,
+    insn_exec,
+    insn_translate,
+    main_loop_wait,
+    mmio_after_read,
+    mmio_before_write,
+    monitor,
+    on_mmap_updated,
+    on_process_end,
+    on_process_start,
+    on_thread_end,
+    on_thread_start,
+    phys_mem_after_read,
+    phys_mem_after_write,
+    phys_mem_before_read,
+    phys_mem_before_write,
+    pre_shutdown,
+    replay_after_dma,
+    replay_before_dma,
+    replay_handle_packet,
+    replay_hd_transfer,
+    replay_net_transfer,
+    replay_serial_read,
+    replay_serial_receive,
+    replay_serial_send,
+    replay_serial_write,
+    top_loop,
+    unassigned_io_read,
+    unassigned_io_write,
+    uninit,
+    virt_mem_after_read,
+    virt_mem_after_write,
+    virt_mem_before_read,
+    virt_mem_before_write,
+};
